# TwoByFour

A double quaternion library for pytorch using cuda.

You need to install PyTorch with cuda support before trying to install TwoByFour, PyTorch is not a managed dependency.

Uses Cutex, which uses Pycuda, to run the cuda code, it compiles at runtime.